@@ -50,7 +50,7 @@ int main(void) {
 	if (setuid(uid)<0) return(6);
 
 	/* Set the SHELL environment variable */
-	if (setenv("SHELL", SHELL, 1)<0) return(7);
+	if (putenv("SHELL=" SHELL)<0) return(7);
 
 	/* Execute our shell. */
 	execl(SHELL, SHELL_SHORT, NULL);
